$$TilesTableProcessedTableManager class
Properties
-
$state
→ TableManagerState
-
The state for this manager
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
prefetchedData
→ List?
-
Prefetched data, if references with prefetching enabled were added to this manager
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asyncMap<N>(FutureOr<N> mapper(dynamic))
→ Selectable<N>
-
Maps this selectable by the
mapper function.
inherited
-
count({bool distinct = true})
→ Future<int>
-
Return the count of rows matched by the built statement
When counting rows, the query will only count distinct rows by default
inherited
-
delete()
→ Future<int>
-
Deletes all rows matched by built statement
inherited
-
exists()
→ Future<bool>
-
Checks whether any rows exist
inherited
-
filter(Expression<bool> f(dynamic f))
→ ProcessedTableManager
-
Add a filter to the statement
inherited
-
get({bool distinct = false, int? limit, int? offset})
→ Future<List>
-
Executes the statement and returns all rows as a list.
inherited
-
getSingle({bool distinct = true})
→ Future
-
Executes this statement, like
get, but only returns one
value. If the query returns no or too many rows, the returned future will
complete with an error.
inherited
-
getSingleOrNull({bool distinct = true})
→ Future
-
Executes this statement, like
get, but only returns one
value. If the result too many values, this method will throw. If no
row is returned, null will be returned instead.
inherited
-
limit(int limit, {int? offset})
→ ProcessedTableManager
-
Add a limit to the statement
inherited
-
map<N>(N mapper(dynamic))
→ Selectable<N>
-
Maps this selectable by the
mapper function.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
orderBy(ComposableOrdering o(dynamic o))
→ ProcessedTableManager
-
Add ordering to the statement
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(Insertable f(dynamic o))
→ Future<int>
-
Writes all non-null fields from the entity into the columns of all rows
that match the
filter clause. Warning: That also means that, when you're
not setting a where clause explicitly, this method will update all rows in
the $state.table.
inherited
-
watch({bool distinct = false, int? limit, int? offset})
→ Stream<List>
-
Creates an auto-updating stream of the result that emits new items
whenever any table used in this statement changes.
inherited
-
watchSingle({bool distinct = true})
→ Stream
-
Creates an auto-updating stream of this statement, similar to
watch. However, it is assumed that the query will only emit
one result, so instead of returning a Stream<List<D>>, this returns a
Stream<D>. If, at any point, the query emits no or more than one rows,
an error will be added to the stream instead.
inherited
-
watchSingleOrNull({bool distinct = true})
→ Stream
-
Creates an auto-updating stream of this statement, similar to
watch. However, it is assumed that the query will only
emit one result, so instead of returning a Stream<List<D>>, this
returns a Stream<D?>. If the query emits more than one row at
some point, an error will be emitted to the stream instead.
If the query emits zero rows at some point, null will be added
to the stream instead.
inherited
-
withFields(Iterable<BaseComputedField<Object, dynamic>> computedFields)
→ ProcessedTableManager
-
Add computed fields to the statement which will be used to add additional columns to the query
These columns will be returned in the result set and can be used in filters/orderings
inherited
-
withReferences([PrefetchHooks prefetch(dynamic prefetch)?])
→ ProcessedTableManager
-
This function with return a new manager which will return each item in the database with its references
inherited