Tile class

Constructors

Tile({required int id, required String source, required int z, required int x, required int y, required Uint8List bytes, String? etag, required DateTime updatedAt, required DateTime lastAccessed})
const
Tile.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

bytes Uint8List
final
etag String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
lastAccessed DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
updatedAt DateTime
final
x int
final
y int
final
z int
final

Methods

copyWith({int? id, String? source, int? z, int? x, int? y, Uint8List? bytes, Value<String?> etag = const Value.absent(), DateTime? updatedAt, DateTime? lastAccessed}) Tile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) TilesCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override