TilesCompanion class

Constructors

TilesCompanion({Value<int> id = const Value.absent(), Value<String> source = const Value.absent(), Value<int> z = const Value.absent(), Value<int> x = const Value.absent(), Value<int> y = const Value.absent(), Value<Uint8List> bytes = const Value.absent(), Value<String?> etag = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<DateTime> lastAccessed = const Value.absent()})
const
TilesCompanion.insert({Value<int> id = const Value.absent(), required String source, required int z, required int x, required int y, required Uint8List bytes, Value<String?> etag = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<DateTime> lastAccessed = const Value.absent()})

Properties

bytes → Value<Uint8List>
final
etag → Value<String?>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
lastAccessed → Value<DateTime>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source → Value<String>
final
updatedAt → Value<DateTime>
final
x → Value<int>
final
y → Value<int>
final
z → Value<int>
final

Methods

copyWith({Value<int>? id, Value<String>? source, Value<int>? z, Value<int>? x, Value<int>? y, Value<Uint8List>? bytes, Value<String?>? etag, Value<DateTime>? updatedAt, Value<DateTime>? lastAccessed}) TilesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? source, Expression<int>? z, Expression<int>? x, Expression<int>? y, Expression<Uint8List>? bytes, Expression<String>? etag, Expression<DateTime>? updatedAt, Expression<DateTime>? lastAccessed}) → Insertable<Tile>