$$TilesTableOrderingComposer class
Constructors
- $$TilesTableOrderingComposer(dynamic $state)
Properties
-
bytes
→ ColumnOrderings<
Uint8List> -
no setter
-
etag
→ ColumnOrderings<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ ColumnOrderings<
int> -
no setter
-
lastAccessed
→ ColumnOrderings<
DateTime> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ ColumnOrderings<
String> -
no setter
-
updatedAt
→ ColumnOrderings<
DateTime> -
no setter
-
x
→ ColumnOrderings<
int> -
no setter
-
y
→ ColumnOrderings<
int> -
no setter
-
z
→ ColumnOrderings<
int> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited